==> odoo_18.0.20251214.zip: odoo-18.0.post20251214/odoo/addons/purchase_product_matrix/static/src/js/purchase_product_field.js <==
/** @odoo-module **/

import { _t } from "@web/core/l10n/translation";
import { registry } from '@web/core/registry';
import { many2OneField } from '@web/views/fields/many2one/many2one_field';
import { ProductMatrixDialog } from "@product_matrix/js/product_matrix_dialog";
import { useService } from "@web/core/utils/hooks";
import { useRecordObserver } from "@web/model/relational_model/utils";
import {
    ProductLabelSectionAndNoteField
} from "@account/components/product_label_section_and_note_field/product_label_section_and_note_field";

export class PurchaseOrderLineProductField extends ProductLabelSectionAndNoteField {
    static template = "purchase.PurchaseProductField";
    setup() {
        super.setup();
        this.dialog = useService("dialog");
        this.currentValue = this.value;

        useRecordObserver((record) => {
            if (record.isInEdition && this.value) {
                if (!this.currentValue || this.currentValue[0] != record.data[this.props.name][0]) {
                    // Field was updated if line was open in edit mode,
                    //      field is not emptied,
                    //      new value is different than existing value.

                    this._onProductTemplateUpdate();
                }
            }
            this.currentValue = record.data[this.props.name];
        });
    }

    get configurationButtonHelp() {
        return _t("Edit Configuration");
    }
    get isConfigurableTemplate() {
        return this.props.record.data.is_configurable_product;
    }

    async _onProductTemplateUpdate() {
        const result = await this.orm.call(
            'product.template',
            'get_single_product_variant',
            [this.props.record.data.product_template_id[0]],
        );
        if(result && result.product_id) {
            if (this.props.record.data.product_id != result.product_id.id) {
                this.props.record.update({
                    // TODO right name get (same problem as configurator)
                    product_id: [result.product_id, result.product_name],
                });
            }
        } else {
            this._openGridConfigurator(false);
        }
    }

    onEditConfiguration() {
        if (this.props.record.data.is_configurable_product) {
            this._openGridConfigurator(true);
        }
    }

    async _openGridConfigurator(edit) {
        const PurchaseOrderRecord = this.props.record.model.root;

        // fetch matrix information from server;
        await PurchaseOrderRecord.update({
            grid_product_tmpl_id: this.props.record.data.product_template_id,
        });

        let updatedLineAttributes = [];
        if (edit) {
            // provide attributes of edited line to automatically focus on matching cell in the matrix
            for (let ptnvav of this.props.record.data.product_no_variant_attribute_value_ids.records) {
                updatedLineAttributes.push(ptnvav.resId);
            }
            for (let ptav of this.props.record.data.product_template_attribute_value_ids.records) {
                updatedLineAttributes.push(ptav.resId);
            }
            updatedLineAttributes.sort((a, b) => { return a - b; });
        }

        this._openMatrixConfigurator(
            PurchaseOrderRecord.data.grid,
            this.props.record.data.product_template_id[0],
            updatedLineAttributes,
        );

        if (!edit) {
            // remove new line used to open the matrix
            PurchaseOrderRecord.data.order_line.delete(this.props.record);
        }
    }

    _openMatrixConfigurator(jsonInfo, productTemplateId, editedCellAttributes) {
        const infos = JSON.parse(jsonInfo);
        this.dialog.add(ProductMatrixDialog, {
            header: infos.header,
            rows: infos.matrix,
            editedCellAttributes: editedCellAttributes.toString(),
            product_template_id: productTemplateId,
            record: this.props.record.model.root,
        });
    }
}

export const purchaseOrderLineProductField = {
    ...many2OneField,
    component: PurchaseOrderLineProductField,
};

registry.category("fields").add("pol_product_many2one", purchaseOrderLineProductField);

==> odoo_19.0.20251016.zip: odoo-19.0.post20251016/odoo/addons/purchase_product_matrix/static/src/js/purchase_product_field.js <==
import { _t } from "@web/core/l10n/translation";
import { registry } from '@web/core/registry';
import { useMatrixConfigurator } from "@product_matrix/js/matrix_configurator_hook";
import { useService } from "@web/core/utils/hooks";
import { useRecordObserver } from "@web/model/relational_model/utils";
import {
    productLabelSectionAndNoteField,
    ProductLabelSectionAndNoteField
} from "@account/components/product_label_section_and_note_field/product_label_section_and_note_field";

export class PurchaseOrderLineProductField extends ProductLabelSectionAndNoteField {
    static template = "purchase.PurchaseProductField";
    setup() {
        super.setup();
        this.orm = useService("orm");
        this.currentValue = this.props.record.data[this.props.name];

        useRecordObserver((record) => {
            if (record.isInEdition && this.props.record.data[this.props.name]) {
                if (!this.currentValue || this.currentValue.id != record.data[this.props.name].id) {
                    // Field was updated if line was open in edit mode,
                    //      field is not emptied,
                    //      new value is different than existing value.

                    this._onProductTemplateUpdate();
                }
            }
            this.currentValue = record.data[this.props.name];
        });
        this.matrixConfigurator = useMatrixConfigurator();
    }

    get configurationButtonHelp() {
        return _t("Edit Configuration");
    }
    get isConfigurableTemplate() {
        return this.props.record.data.is_configurable_product;
    }

    async _onProductTemplateUpdate() {
        const result = await this.orm.call(
            'product.template',
            'get_single_product_variant',
            [this.props.record.data.product_template_id.id],
        );
        if(result && result.product_id) {
            if (this.props.record.data.product_id != result.product_id.id) {
                this.props.record.update({
                    // TODO right name get (same problem as configurator)
                    product_id: { id: result.product_id, display_name: result.product_name },
                });
            }
        } else {
            this.matrixConfigurator.open(this.props.record, false);
        }
    }

    onEditConfiguration() {
        if (this.props.record.data.is_configurable_product) {
            this.matrixConfigurator.open(this.props.record, true);
        }
    }
}

registry.category("fields").add("pol_product_many2one", {
    ...productLabelSectionAndNoteField,
    component: PurchaseOrderLineProductField,
});
